@@ -60,3 +60,8 @@ class Webhook:
                 )
 
         return response
+
+
+def getWebhookMiddlewareClass(response):
+    get_webhook_middleware_class = webhook_settings.GET_WEBHOOK_MIDDLEWARE_CLASS(response)
+    return get_webhook_middleware_class
\ No newline at end of file
